redvox.cloud API documentation

# Module `redvox.cloud`

## Sub-modules

`redvox.cloud.api`

  This module contains methods for interacting with the RedVox cloud based API.

`redvox.cloud.api_m_fqns`
`redvox.cloud.auth_api`

  This module contains classes and functions for interacting with the RedVox Cloud API authentication endpoints.

`redvox.cloud.client`

  This module contains the RedVox Cloud API client …

`redvox.cloud.config`

  This module contains capabilities for loading RedVox specific configurations from the user's environment if it exists.

`redvox.cloud.data_api`

  This module contains API definitions and functions for working with raw RedVox data packets.

`redvox.cloud.data_client`

  This module provides a custom work-stealing thread pool for downloading API M data in parallel.

`redvox.cloud.data_io`

  This module contains functions for downloading data from AWS S3 via signed URLs.

`redvox.cloud.errors`

  Custom defined RedVox Cloud derived errors.

`redvox.cloud.metadata_api`

  This module contains classes and enums for working with generic RedVox packet metadata through the cloud API.

`redvox.cloud.query_timing_correction`

  This module contains classes and routines for performing timing corrections on cloud based ranged queries.

`redvox.cloud.routes`

  This module contains the route definitions for interacting with the RedVox Cloud API.

`redvox.cloud.station_stats`

  This module provides access to the timing station statistics through the RedVox Cloud API.